@@ -2,6 +2,7 @@
 #'
 #' @param packages Packages to add
 #' @param remotes Remotes to add
+#' @return No return value
 #' @export
 #' @examples \dontrun{
 #'
@@ -17,8 +18,6 @@
 #' }
 add <- function(packages, remotes=c()) {
   sandbox({
-    prepCommand()
-
     desc <- updateDesc(packages, remotes)
 
     installHelper(desc=desc, show_status=TRUE)
