@@ -16,7 +16,7 @@ outdated <- function() {
     outdated <- deps[deps$diff == -1, ]
 
     if (nrow(outdated) > 0) {
-      for (i in 1:nrow(outdated)) {
+      for (i in seq_len(nrow(outdated))) {
         row <- outdated[i, ]
         message(paste0(row$package, " (latest ", row$available, ", installed ", row$installed, ")"))
       }
